==> jc-1.4.0.tar.gz: polyglot/ast/Binary__24Operator.h <==
// public class polyglot.ast.Binary$Operator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f7a7478dc07f2986 polyglot_ast_Binary__24Operator
// @dep_class 82f09079602e8c27 polyglot_util_Enum

// header file dependencies
// @dep_header polyglot_util_Enum

#include "polyglot/util/Enum.h"

#ifndef _JC_polyglot_ast_Binary__24Operator_H_
#define _JC_polyglot_ast_Binary__24Operator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_Precedence$object;

// Typedefs
typedef struct _jc_polyglot_ast_Binary__24Operator$sub_refs	_jc_polyglot_ast_Binary__24Operator$sub_refs;
typedef struct _jc_polyglot_ast_Binary__24Operator$sub_nonrefs	_jc_polyglot_ast_Binary__24Operator$sub_nonrefs;
typedef struct _jc_polyglot_ast_Binary__24Operator$refs	_jc_polyglot_ast_Binary__24Operator$refs;
typedef struct _jc_polyglot_ast_Binary__24Operator$nonrefs	_jc_polyglot_ast_Binary__24Operator$nonrefs;
typedef struct _jc_polyglot_ast_Binary__24Operator$object	_jc_polyglot_ast_Binary__24Operator$object;

typedef const struct _jc_polyglot_ast_Binary__24Operator$vmethods	_jc_polyglot_ast_Binary__24Operator$vmethods;
typedef const struct _jc_polyglot_ast_Binary__24Operator$vtable	_jc_polyglot_ast_Binary__24Operator$vtable;
typedef const struct _jc_polyglot_ast_Binary__24Operator$vtype	_jc_polyglot_ast_Binary__24Operator$vtype;

// Constructors
extern void _jc_polyglot_ast_Binary__24Operator$method$_init$b50c1c41279523d3(_jc_env *, struct _jc_polyglot_ast_Binary__24Operator$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_ast_Precedence$object *);

// Virtual methods
extern struct _jc_polyglot_ast_Precedence$object *_jc_polyglot_ast_Binary__24Operator$method$precedence$334b0140c8dd854d(_jc_env *, struct _jc_polyglot_ast_Binary__24Operator$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ast_Binary__24Operator$method_info$precedence$334b0140c8dd854d;

// Virtual methods structure
struct _jc_polyglot_ast_Binary__24Operator$vmethods {
	struct _jc_polyglot_ast_Precedence$object	*(*precedence$334b0140c8dd854d)(_jc_env *, struct _jc_polyglot_ast_Binary__24Operator$object *);
};

// Vtable
struct _jc_polyglot_ast_Binary__24Operator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Enum$vmethods	polyglot_util_Enum;
	_jc_polyglot_ast_Binary__24Operator$vmethods	polyglot_ast_Binary__24Operator;
};

// Vtype
struct _jc_polyglot_ast_Binary__24Operator$vtype {
	_jc_type			type;
	_jc_polyglot_ast_Binary__24Operator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ast_Binary__24Operator$sub_refs {
	struct _jc_polyglot_ast_Precedence$object	*prec;
};

// Reference instance fields (object)
struct _jc_polyglot_ast_Binary__24Operator$refs {
    _jc_polyglot_ast_Binary__24Operator$sub_refs	polyglot_ast_Binary__24Operator;
    _jc_polyglot_util_Enum$sub_refs	polyglot_util_Enum;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ast_Binary__24Operator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ast_Binary__24Operator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Enum$sub_nonrefs	polyglot_util_Enum;
    _jc_polyglot_ast_Binary__24Operator$sub_nonrefs	polyglot_ast_Binary__24Operator;
};

// Object instance structure
struct _jc_polyglot_ast_Binary__24Operator$object {
	_jc_polyglot_ast_Binary__24Operator$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ast_Binary__24Operator$vtype	*vtype;
	_jc_polyglot_ast_Binary__24Operator$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ast_Binary__24Operator$vtype _jc_polyglot_ast_Binary__24Operator$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ast_Binary__24Operator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ast_Binary__24Operator$class_object;

#endif	/* _JC_polyglot_ast_Binary__24Operator_H_ */

==> jc-1.4.6.tar.gz: polyglot/ast/Binary__24Operator.h <==
// public class polyglot.ast.Binary$Operator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f7a7478dc07f2986 polyglot_ast_Binary__24Operator
// @dep_class 82f09079602e8c27 polyglot_util_Enum

// header file dependencies
// @dep_header polyglot_util_Enum

#include "polyglot/util/Enum.h"

#ifndef _JC_polyglot_ast_Binary__24Operator_H_
#define _JC_polyglot_ast_Binary__24Operator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_Precedence$object;

// Typedefs
typedef struct _jc_polyglot_ast_Binary__24Operator$sub_refs	_jc_polyglot_ast_Binary__24Operator$sub_refs;
typedef struct _jc_polyglot_ast_Binary__24Operator$sub_nonrefs	_jc_polyglot_ast_Binary__24Operator$sub_nonrefs;
typedef struct _jc_polyglot_ast_Binary__24Operator$refs	_jc_polyglot_ast_Binary__24Operator$refs;
typedef struct _jc_polyglot_ast_Binary__24Operator$nonrefs	_jc_polyglot_ast_Binary__24Operator$nonrefs;
typedef struct _jc_polyglot_ast_Binary__24Operator$object	_jc_polyglot_ast_Binary__24Operator$object;

typedef const struct _jc_polyglot_ast_Binary__24Operator$vmethods	_jc_polyglot_ast_Binary__24Operator$vmethods;
typedef const struct _jc_polyglot_ast_Binary__24Operator$vtable	_jc_polyglot_ast_Binary__24Operator$vtable;
typedef const struct _jc_polyglot_ast_Binary__24Operator$vtype	_jc_polyglot_ast_Binary__24Operator$vtype;

// Constructors
extern void _jc_polyglot_ast_Binary__24Operator$method$_init$b50c1c41279523d3(_jc_env *, struct _jc_polyglot_ast_Binary__24Operator$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_ast_Precedence$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_polyglot_ast_Precedence$object *_jc_polyglot_ast_Binary__24Operator$method$precedence$334b0140c8dd854d(_jc_env *, struct _jc_polyglot_ast_Binary__24Operator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ast_Binary__24Operator$method_info$precedence$334b0140c8dd854d;

// Virtual methods structure
struct _jc_polyglot_ast_Binary__24Operator$vmethods {
	struct _jc_polyglot_ast_Precedence$object	*(*precedence$334b0140c8dd854d)(_jc_env *, struct _jc_polyglot_ast_Binary__24Operator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ast_Binary__24Operator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Enum$vmethods	polyglot_util_Enum;
	_jc_polyglot_ast_Binary__24Operator$vmethods	polyglot_ast_Binary__24Operator;
};

// Vtype
struct _jc_polyglot_ast_Binary__24Operator$vtype {
	_jc_type			type;
	_jc_polyglot_ast_Binary__24Operator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ast_Binary__24Operator$sub_refs {
	struct _jc_polyglot_ast_Precedence$object	*prec;
};

// Reference instance fields (object)
struct _jc_polyglot_ast_Binary__24Operator$refs {
    _jc_polyglot_ast_Binary__24Operator$sub_refs	polyglot_ast_Binary__24Operator;
    _jc_polyglot_util_Enum$sub_refs	polyglot_util_Enum;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ast_Binary__24Operator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ast_Binary__24Operator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Enum$sub_nonrefs	polyglot_util_Enum;
    _jc_polyglot_ast_Binary__24Operator$sub_nonrefs	polyglot_ast_Binary__24Operator;
};

// Object instance structure
struct _jc_polyglot_ast_Binary__24Operator$object {
	_jc_polyglot_ast_Binary__24Operator$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ast_Binary__24Operator$vtype	*vtype;
	_jc_polyglot_ast_Binary__24Operator$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ast_Binary__24Operator$vtype _jc_polyglot_ast_Binary__24Operator$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ast_Binary__24Operator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ast_Binary__24Operator$class_object;

#endif	/* _JC_polyglot_ast_Binary__24Operator_H_ */
